# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/core/security.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/core/security.proto',
  package='flyteidl.core',
  syntax='proto3',
  serialized_options=_b('Z4github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/core'),
  serialized_pb=_b('\n\x1c\x66lyteidl/core/security.proto\x12\rflyteidl.core\"\xa4\x01\n\x06Secret\x12\r\n\x05group\x18\x01 \x01(\t\x12\x15\n\rgroup_version\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12:\n\x11mount_requirement\x18\x04 \x01(\x0e\x32\x1f.flyteidl.core.Secret.MountType\"+\n\tMountType\x12\x07\n\x03\x41NY\x10\x00\x12\x0b\n\x07\x45NV_VAR\x10\x01\x12\x08\n\x04\x46ILE\x10\x02\"O\n\x0cOAuth2Client\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12,\n\rclient_secret\x18\x02 \x01(\x0b\x32\x15.flyteidl.core.Secret\"m\n\x08Identity\x12\x10\n\x08iam_role\x18\x01 \x01(\t\x12\x1b\n\x13k8s_service_account\x18\x02 \x01(\t\x12\x32\n\roauth2_client\x18\x03 \x01(\x0b\x32\x1b.flyteidl.core.OAuth2Client\"\xdd\x01\n\x12OAuth2TokenRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x34\n\x04type\x18\x02 \x01(\x0e\x32&.flyteidl.core.OAuth2TokenRequest.Type\x12+\n\x06\x63lient\x18\x03 \x01(\x0b\x32\x1b.flyteidl.core.OAuth2Client\x12\x1e\n\x16idp_discovery_endpoint\x18\x04 \x01(\t\x12\x16\n\x0etoken_endpoint\x18\x05 \x01(\t\"\x1e\n\x04Type\x12\x16\n\x12\x43LIENT_CREDENTIALS\x10\x00\"\x95\x01\n\x0fSecurityContext\x12\'\n\x06run_as\x18\x01 \x01(\x0b\x32\x17.flyteidl.core.Identity\x12&\n\x07secrets\x18\x02 \x03(\x0b\x32\x15.flyteidl.core.Secret\x12\x31\n\x06tokens\x18\x03 \x03(\x0b\x32!.flyteidl.core.OAuth2TokenRequestB6Z4github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/coreb\x06proto3')
)



_SECRET_MOUNTTYPE = _descriptor.EnumDescriptor(
  name='MountType',
  full_name='flyteidl.core.Secret.MountType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ANY', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENV_VAR', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FILE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=169,
  serialized_end=212,
)
_sym_db.RegisterEnumDescriptor(_SECRET_MOUNTTYPE)

_OAUTH2TOKENREQUEST_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='flyteidl.core.OAuth2TokenRequest.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CLIENT_CREDENTIALS', index=0, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=598,
  serialized_end=628,
)
_sym_db.RegisterEnumDescriptor(_OAUTH2TOKENREQUEST_TYPE)


_SECRET = _descriptor.Descriptor(
  name='Secret',
  full_name='flyteidl.core.Secret',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group', full_name='flyteidl.core.Secret.group', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group_version', full_name='flyteidl.core.Secret.group_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key', full_name='flyteidl.core.Secret.key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mount_requirement', full_name='flyteidl.core.Secret.mount_requirement', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SECRET_MOUNTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48,
  serialized_end=212,
)


_OAUTH2CLIENT = _descriptor.Descriptor(
  name='OAuth2Client',
  full_name='flyteidl.core.OAuth2Client',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='flyteidl.core.OAuth2Client.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_secret', full_name='flyteidl.core.OAuth2Client.client_secret', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=293,
)


_IDENTITY = _descriptor.Descriptor(
  name='Identity',
  full_name='flyteidl.core.Identity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='iam_role', full_name='flyteidl.core.Identity.iam_role', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='k8s_service_account', full_name='flyteidl.core.Identity.k8s_service_account', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oauth2_client', full_name='flyteidl.core.Identity.oauth2_client', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=295,
  serialized_end=404,
)


_OAUTH2TOKENREQUEST = _descriptor.Descriptor(
  name='OAuth2TokenRequest',
  full_name='flyteidl.core.OAuth2TokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='flyteidl.core.OAuth2TokenRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='flyteidl.core.OAuth2TokenRequest.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client', full_name='flyteidl.core.OAuth2TokenRequest.client', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='idp_discovery_endpoint', full_name='flyteidl.core.OAuth2TokenRequest.idp_discovery_endpoint', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token_endpoint', full_name='flyteidl.core.OAuth2TokenRequest.token_endpoint', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OAUTH2TOKENREQUEST_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=407,
  serialized_end=628,
)


_SECURITYCONTEXT = _descriptor.Descriptor(
  name='SecurityContext',
  full_name='flyteidl.core.SecurityContext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='run_as', full_name='flyteidl.core.SecurityContext.run_as', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secrets', full_name='flyteidl.core.SecurityContext.secrets', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tokens', full_name='flyteidl.core.SecurityContext.tokens', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=631,
  serialized_end=780,
)

_SECRET.fields_by_name['mount_requirement'].enum_type = _SECRET_MOUNTTYPE
_SECRET_MOUNTTYPE.containing_type = _SECRET
_OAUTH2CLIENT.fields_by_name['client_secret'].message_type = _SECRET
_IDENTITY.fields_by_name['oauth2_client'].message_type = _OAUTH2CLIENT
_OAUTH2TOKENREQUEST.fields_by_name['type'].enum_type = _OAUTH2TOKENREQUEST_TYPE
_OAUTH2TOKENREQUEST.fields_by_name['client'].message_type = _OAUTH2CLIENT
_OAUTH2TOKENREQUEST_TYPE.containing_type = _OAUTH2TOKENREQUEST
_SECURITYCONTEXT.fields_by_name['run_as'].message_type = _IDENTITY
_SECURITYCONTEXT.fields_by_name['secrets'].message_type = _SECRET
_SECURITYCONTEXT.fields_by_name['tokens'].message_type = _OAUTH2TOKENREQUEST
DESCRIPTOR.message_types_by_name['Secret'] = _SECRET
DESCRIPTOR.message_types_by_name['OAuth2Client'] = _OAUTH2CLIENT
DESCRIPTOR.message_types_by_name['Identity'] = _IDENTITY
DESCRIPTOR.message_types_by_name['OAuth2TokenRequest'] = _OAUTH2TOKENREQUEST
DESCRIPTOR.message_types_by_name['SecurityContext'] = _SECURITYCONTEXT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Secret = _reflection.GeneratedProtocolMessageType('Secret', (_message.Message,), dict(
  DESCRIPTOR = _SECRET,
  __module__ = 'flyteidl.core.security_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.core.Secret)
  ))
_sym_db.RegisterMessage(Secret)

OAuth2Client = _reflection.GeneratedProtocolMessageType('OAuth2Client', (_message.Message,), dict(
  DESCRIPTOR = _OAUTH2CLIENT,
  __module__ = 'flyteidl.core.security_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.core.OAuth2Client)
  ))
_sym_db.RegisterMessage(OAuth2Client)

Identity = _reflection.GeneratedProtocolMessageType('Identity', (_message.Message,), dict(
  DESCRIPTOR = _IDENTITY,
  __module__ = 'flyteidl.core.security_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.core.Identity)
  ))
_sym_db.RegisterMessage(Identity)

OAuth2TokenRequest = _reflection.GeneratedProtocolMessageType('OAuth2TokenRequest', (_message.Message,), dict(
  DESCRIPTOR = _OAUTH2TOKENREQUEST,
  __module__ = 'flyteidl.core.security_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.core.OAuth2TokenRequest)
  ))
_sym_db.RegisterMessage(OAuth2TokenRequest)

SecurityContext = _reflection.GeneratedProtocolMessageType('SecurityContext', (_message.Message,), dict(
  DESCRIPTOR = _SECURITYCONTEXT,
  __module__ = 'flyteidl.core.security_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.core.SecurityContext)
  ))
_sym_db.RegisterMessage(SecurityContext)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/admin/notification.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/admin/notification.proto',
  package='flyteidl.admin',
  syntax='proto3',
  serialized_options=_b('Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/admin'),
  serialized_pb=_b('\n!flyteidl/admin/notification.proto\x12\x0e\x66lyteidl.admin\"b\n\x0c\x45mailMessage\x12\x18\n\x10recipients_email\x18\x01 \x03(\t\x12\x14\n\x0csender_email\x18\x02 \x01(\t\x12\x14\n\x0csubject_line\x18\x03 \x01(\t\x12\x0c\n\x04\x62ody\x18\x04 \x01(\tB7Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/adminb\x06proto3')
)




_EMAILMESSAGE = _descriptor.Descriptor(
  name='EmailMessage',
  full_name='flyteidl.admin.EmailMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='recipients_email', full_name='flyteidl.admin.EmailMessage.recipients_email', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sender_email', full_name='flyteidl.admin.EmailMessage.sender_email', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subject_line', full_name='flyteidl.admin.EmailMessage.subject_line', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='flyteidl.admin.EmailMessage.body', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=53,
  serialized_end=151,
)

DESCRIPTOR.message_types_by_name['EmailMessage'] = _EMAILMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EmailMessage = _reflection.GeneratedProtocolMessageType('EmailMessage', (_message.Message,), dict(
  DESCRIPTOR = _EMAILMESSAGE,
  __module__ = 'flyteidl.admin.notification_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.EmailMessage)
  ))
_sym_db.RegisterMessage(EmailMessage)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
